@@ -9,7 +9,6 @@ LibHalContext* CameraKey::halctx;
 int CameraKey::shutter_state;
 bool CameraKey::timeExpired;
 
-
 CameraKey* CameraKey::me=NULL;
 
 CameraKey::CameraKey(Launcher* launcher_):launcher(launcher_)
@@ -117,6 +116,14 @@ bool CameraKey::doShortPress()
 		launcher->Menu();
     if (shortPress.compare("backspace")==0)
         launcher->Backspace();
+    if (shortPress.compare("usermenu")==0)
+        launcher->userMenu();
+	if (shortPress.compare("shellcommand")==0)
+		launcher->shellCommand();
+    if (shortPress.compare("textreflow")==0)
+        launcher->TextReflow();
+    if (shortPress.compare("rotation")==0)
+        launcher->Rotation();
 
 	return true;
 }
@@ -132,6 +139,15 @@ bool CameraKey::doLongPress()
 		launcher->Menu();
 	if (longPress.compare("backspace")==0)
 		launcher->Backspace();
+	if (longPress.compare("usermenu")==0)
+		launcher->userMenu();
+	if (longPress.compare("shellcommand")==0)
+		launcher->shellCommand();
+    if (longPress.compare("textreflow")==0)
+        launcher->TextReflow();
+    if (longPress.compare("rotation")==0)
+        launcher->Rotation();
+
 
 	return true;
 }
@@ -148,4 +164,3 @@ void CameraKey::AlarmHandler(int sig)
 	DebugPrint("long press");
 	me->doLongPress();
 }
-
