@@ -46,6 +46,7 @@ class Config
 		int readConfig();
 		void writeConfigFile();	
 
+		int proximityVibrateOn;
 		int proximityOn;
 		int camerakeyOn;
 		std::string ps_shortPress;
@@ -53,6 +54,7 @@ class Config
 		std::string ps_hold;
 		std::string ck_shortPress;
 		std::string ck_longPress;
+		std::string shellCommand;
 
 		void setProximity(ProximitySensor* ps_);
 		void setCameraKey(CameraKey* ck_);
