@@ -3,10 +3,12 @@
 #include "config.h"
 
 #include <iostream>
+#include <string>
 #include <stdlib.h>
 
 #include <ctype.h>
 #include <X11/Xlib.h>
+#include <X11/Xutil.h>
 #include <X11/extensions/XTest.h>
 #include <unistd.h>
 
@@ -20,7 +22,6 @@
 #include <sys/stat.h>
 
 
-
 class Launcher
 {
 	public:
@@ -31,10 +32,21 @@ class Launcher
 	
 	bool Dashboard();
 	bool Backspace();
+	bool Rotation();
+	bool TextReflow();
 	bool Phone();
 	bool Menu();
+	bool userMenu();
+	bool shellCommand();
+
+	bool execShellCommand(std::string cmd);
+	bool isCameraUiOpen();
 	
-	// also possibly a function to launch any user-configurable app?
+	void StartZoom();
+	void StopZoom();
+	static gboolean GetPointerPos(gpointer data);
+
+	std::string defaultShellCommand;
 
 	private:
 
@@ -63,7 +75,12 @@ class Launcher
 
 		bool connectToDbusPhone();
 
-	
+			static Display* stc_dpy;
+			static Window stc_win;
+			static bool stc_grab;
+			static int stc_pointer_oldx;
+			static int stc_pointer_oldy;
+
 };
 
 
