@@ -9,14 +9,16 @@
 
 const int debug = 0;
 
+void checkButtonToggle( HildonCheckButton* arg0, gpointer user_data);
 int getSelectorIndex(std::vector<std::string> actions_, std::string configStr_);
 
-
 osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activated)
 {
-	GtkWidget *dialog, *banner, *pannable, *vbox, *check_cam, *check_prox,
-		*pick_proxshort, *pick_proxlong, *pick_camshort, *pick_camlong,
-		*select_proxshort, *select_proxlong, *select_camshort, *select_camlong;
+	GtkWidget *dialog, *banner, *pannable, *vbox, *vbox_camkey, *vbox_prox, *align_camkey, *align_prox,
+		*check_cam, *check_prox, *check_proxvibra,
+		*check_proxhold, *pick_proxshort, *pick_proxlong, *pick_camshort, *pick_camlong,
+		*select_proxshort, *select_proxlong, *select_camshort, *select_camlong,
+		*label_shellcommand, *text_shellcommand;
 	gint response;
 	
 	Config* conf = new Config(NULL, NULL);
@@ -34,6 +36,13 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 
 	pannable = hildon_pannable_area_new();
 	vbox = gtk_vbox_new(FALSE,0);
+	vbox_camkey = gtk_vbox_new(FALSE,0);
+	vbox_prox = gtk_vbox_new(FALSE,0);
+
+	align_camkey = gtk_alignment_new(1, 0.5, 1, 1);
+	align_prox = gtk_alignment_new(1, 0.5, 1, 1);
+	gtk_alignment_set_padding(GTK_ALIGNMENT(align_camkey), 0, 10, 48, 0);
+	gtk_alignment_set_padding(GTK_ALIGNMENT(align_prox), 0, 0, 48, 0);
 
 	check_cam = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
 	gtk_button_set_label(GTK_BUTTON(check_cam), "Use the camera button");
@@ -41,13 +50,19 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	check_prox = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
 	gtk_button_set_label(GTK_BUTTON(check_prox), "Use the proximity sensor");
 
+    check_proxvibra = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+    gtk_button_set_label(GTK_BUTTON(check_proxvibra), "Proximity sensor vibration");
+
+    check_proxhold = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+    gtk_button_set_label(GTK_BUTTON(check_proxhold), "Toggle prox. sensor by very long touch");
+
 	pick_proxshort = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT,
 		HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-	hildon_button_set_title(HILDON_BUTTON(pick_proxshort), "Proximity sensor short press action");
+	hildon_button_set_title(HILDON_BUTTON(pick_proxshort), "Proximity sensor short touch action");
 
 	pick_proxlong = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT,
         HILDON_BUTTON_ARRANGEMENT_VERTICAL);
-    hildon_button_set_title(HILDON_BUTTON(pick_proxlong), "Proximity sensor long press action");
+    hildon_button_set_title(HILDON_BUTTON(pick_proxlong), "Proximity sensor long touch action");
 
 	pick_camshort = hildon_picker_button_new(HILDON_SIZE_FINGER_HEIGHT,
         HILDON_BUTTON_ARRANGEMENT_VERTICAL);
@@ -77,7 +92,11 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
     select_proxlong = hildon_touch_selector_new_text();
     hildon_touch_selector_set_column_selection_mode(HILDON_TOUCH_SELECTOR(select_proxlong),
 		HILDON_TOUCH_SELECTOR_SELECTION_MODE_SINGLE);
-	
+
+	text_shellcommand = hildon_entry_new(HILDON_SIZE_AUTO);
+	label_shellcommand = gtk_label_new("Custom shell command:");
+	gtk_misc_set_alignment( GTK_MISC(label_shellcommand), 0.0, 0.5);	
+
 	// the lengths of these vectors must match!
 	std::vector<std::string> launch_descriptions;
 	launch_descriptions.push_back("Disabled");
@@ -85,6 +104,10 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	launch_descriptions.push_back("Launch phone");
 	launch_descriptions.push_back("Menu");
 	launch_descriptions.push_back("Backspace (Browser: back)");
+	launch_descriptions.push_back("Ctrl-shift-r (Enable rotation)");
+	//launch_descriptions.push_back("Browser text reflow");
+	//launch_descriptions.push_back("Shortcutd user menu");
+	launch_descriptions.push_back("Custom shell command");
 
 	std::vector<std::string> launch_actions;
 	launch_actions.push_back("disabled");
@@ -92,6 +115,10 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	launch_actions.push_back("phone");
 	launch_actions.push_back("menu");
 	launch_actions.push_back("backspace");
+	launch_actions.push_back("rotation");
+	//launch_actions.push_back("textreflow");
+	//launch_actions.push_back("usermenu");
+	launch_actions.push_back("shellcommand");
 
 	for(unsigned int i=0; i<launch_descriptions.size(); i++)
 	{
@@ -110,12 +137,23 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
     hildon_picker_button_set_selector(HILDON_PICKER_BUTTON(pick_camlong),
         HILDON_TOUCH_SELECTOR(select_camlong));	
 
+    gtk_box_pack_start(GTK_BOX(vbox_camkey), pick_camshort, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox_camkey), pick_camlong, FALSE, FALSE, 0);
+
+    gtk_box_pack_start(GTK_BOX(vbox_prox), pick_proxshort, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox_prox), pick_proxlong, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox_prox), check_proxvibra, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(vbox_prox), check_proxhold, FALSE, FALSE, 0);
+
+	gtk_container_add(GTK_CONTAINER(align_camkey), vbox_camkey);
+	gtk_container_add(GTK_CONTAINER(align_prox), vbox_prox);
+
 	gtk_box_pack_start(GTK_BOX(vbox), check_cam, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(vbox), pick_camshort, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(vbox), pick_camlong, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), align_camkey, FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), check_prox, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), pick_proxshort, FALSE, FALSE, 0);
-	gtk_box_pack_start(GTK_BOX(vbox), pick_proxlong, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), align_prox, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), label_shellcommand, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vbox), text_shellcommand, FALSE, FALSE, 0);
 
 	hildon_pannable_area_set_size_request_policy(
 		HILDON_PANNABLE_AREA(pannable), HILDON_SIZE_REQUEST_CHILDREN);
@@ -126,11 +164,25 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	// set the widget values from config
 	hildon_check_button_set_active(HILDON_CHECK_BUTTON(check_cam), (gboolean)conf->camerakeyOn);
 	hildon_check_button_set_active(HILDON_CHECK_BUTTON(check_prox), (gboolean)conf->proximityOn);
+	hildon_check_button_set_active(HILDON_CHECK_BUTTON(check_proxvibra), (gboolean)conf->proximityVibrateOn);
+	if( conf->ps_hold == "proximityToggle" ) {
+		hildon_check_button_set_active(HILDON_CHECK_BUTTON(check_proxhold), TRUE);
+	} else {
+		hildon_check_button_set_active(HILDON_CHECK_BUTTON(check_proxhold), FALSE);
+	}
 	hildon_picker_button_set_active(HILDON_PICKER_BUTTON(pick_camshort), getSelectorIndex(launch_actions, conf->ck_shortPress));
 	hildon_picker_button_set_active(HILDON_PICKER_BUTTON(pick_camlong), getSelectorIndex(launch_actions, conf->ck_longPress));
 	hildon_picker_button_set_active(HILDON_PICKER_BUTTON(pick_proxshort), getSelectorIndex(launch_actions, conf->ps_shortPress));
 	hildon_picker_button_set_active(HILDON_PICKER_BUTTON(pick_proxlong), getSelectorIndex(launch_actions, conf->ps_longPress));
 
+	gtk_widget_set_sensitive(vbox_camkey, (gboolean)conf->camerakeyOn);
+	gtk_widget_set_sensitive(vbox_prox, (gboolean)conf->proximityOn);
+
+	gtk_signal_connect(GTK_OBJECT(check_cam), "toggled", GTK_SIGNAL_FUNC(checkButtonToggle), vbox_camkey);
+	gtk_signal_connect(GTK_OBJECT(check_prox), "toggled", GTK_SIGNAL_FUNC(checkButtonToggle), vbox_prox);
+
+	hildon_entry_set_text(HILDON_ENTRY(text_shellcommand),conf->shellCommand.c_str());
+
 	gtk_widget_show_all(dialog);
 
 	if (!user_activated)
@@ -143,11 +195,14 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 
 	if (response == GTK_RESPONSE_OK)
 	{
-		// maybe should check if settings have really changed before
-		// writing, restarting & killing
-
 		conf->proximityOn = (int)hildon_check_button_get_active(HILDON_CHECK_BUTTON(check_prox));
-		conf->camerakeyOn = (int)hildon_check_button_get_active(HILDON_CHECK_BUTTON(check_cam));;
+		conf->camerakeyOn = (int)hildon_check_button_get_active(HILDON_CHECK_BUTTON(check_cam));
+		conf->proximityVibrateOn = (int)hildon_check_button_get_active(HILDON_CHECK_BUTTON(check_proxvibra));
+		if( hildon_check_button_get_active(HILDON_CHECK_BUTTON(check_proxhold)) == TRUE ) {
+			conf->ps_hold = "proximityToggle";
+		} else {
+			conf->ps_hold = "disabled";
+		}
 		if( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_proxshort)) != -1 )
 			conf->ps_shortPress = launch_actions.at( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_proxshort)) );
 		if( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_proxlong)) != -1 )
@@ -156,6 +211,7 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 			conf->ck_shortPress = launch_actions.at( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_camshort)) );
 		if( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_camlong)) != -1 )
 			conf->ck_longPress = launch_actions.at( hildon_picker_button_get_active(HILDON_PICKER_BUTTON(pick_camlong)) );
+		conf->shellCommand = hildon_entry_get_text(HILDON_ENTRY(text_shellcommand));
 
 		conf->writeConfigFile();
 
@@ -177,6 +233,11 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	return OSSO_OK;
 }
 
+void checkButtonToggle( HildonCheckButton* arg0, gpointer user_data)
+{
+    gtk_widget_set_sensitive(GTK_WIDGET(user_data), hildon_check_button_get_active(HILDON_CHECK_BUTTON(arg0)) );
+}
+
 int getSelectorIndex(std::vector<std::string> actions_, std::string configStr_)
 {
 	int i=0;
