@@ -17,7 +17,7 @@ ProximitySensor::ProximitySensor(Launcher* launcher_):launcher(launcher_)
 	longPress="phone";
 	hold="proximityToggle";
 
-	paramVib="PatternTocuhScreen";
+	paramVib="PatternTouchscreen";
 
 	tap=0;
 	on=1;
@@ -381,6 +381,14 @@ void ProximitySensor::doShortPress()
 		launcher->Menu();
     if (shortPress.compare("backspace")==0)
         launcher->Backspace();
+    if (shortPress.compare("usermenu")==0)
+        launcher->userMenu();
+	if (shortPress.compare("shellcommand")==0)
+        launcher->shellCommand();
+    if (shortPress.compare("textreflow")==0)
+		launcher->TextReflow();
+    if (shortPress.compare("rotation")==0)      
+        launcher->Rotation();
 
 }
 
@@ -394,6 +402,14 @@ void ProximitySensor::doLongPress()
 		launcher->Menu();
     if (longPress.compare("backspace")==0)
         launcher->Backspace();
+    if (longPress.compare("usermenu")==0)
+        launcher->userMenu();
+	if (longPress.compare("shellcommand")==0)
+		launcher->shellCommand();
+	if (longPress.compare("textreflow")==0)
+    	launcher->TextReflow();
+    if (longPress.compare("rotation")==0)
+        launcher->Rotation();
 }
 
 
